==> nextcloud-26.0.7p0.tgz: nextcloud/apps/activity/l10n/vi.js <==
OC.L10N.register(
    "activity",
    {
    "Copied!" : "Đã sao chép!",
    "Not supported!" : "Không được hỗ trợ!",
    "Press ⌘-C to copy." : "Ấn ⌘-C để sao chép",
    "Press Ctrl-C to copy." : "Ấn Ctrl-C để sao chép",
    "{name} (invisible)" : "{name} (ẩn)",
    "{name} (restricted)" : "{name} (hạn chế)",
    "Home" : "Trang chủ",
    "in {path}" : "trong {path}",
    "This stream will show events like additions, changes & shares" : "Luồng này sẽ hiển thị các sự kiện như bổ sung, thay đổi & chia sẻ",
    "There are no events for this filter" : "Không có sự kiện nào cho bộ lọc này",
    "Today" : "Hôm nay",
    "Yesterday" : "Hôm qua",
    "Open {filename}" : "Mở {filename}",
    "Activity" : "Hoạt động",
    "Personal activity feed for %s" : "Khay hoạt động cá nhân được %s",
    "Your feed URL is invalid" : "Khay URL của bạn không hợp lệ",
    "Your settings have been updated." : "Các thiết lập của bạn vừa được cập nhật",
    "Settings have been updated." : "Các cài đặt đã được cập nhật.",
    "Recent activity" : "Hoạt động gần đây",
    "No activities" : "Không có hoạt động",
    "More activities" : "Hoạt động mở rộng",
    "Daily activity summary for %s" : "Tóm tắt hoạt động hàng ngày cho %s",
    "_and %n more _::_and %n more _" : ["và %n thêm"],
    "All activities" : "Tất cả hoạt động",
    "By others" : "Bởi người khác",
    "By you" : "Bởi bạn",
    "Activity at %s" : "Hoạt động ở %s",
    "Hello %s" : "Xin chào %s",
    "Hello %s," : "Xin chào %s,",
    "There was some activity at %s" : "Có một số hoạt động tại %s",
    "Mail" : "Thư điện tử",
    "Push" : "Đẩy",
    "Notifications" : "Thông báo",
    "This application enables people to view a log of activities about them, their files or other data." : "Ứng dụng này cho phép người dùng xem ghi chép cá nhân của họ về: các hoạt động gần đây, tệp tin hoặc dữ liệu khác.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Ứng dụng này cho phép người dùng xem các thao tác liên quan đến tệp tin và dữ liệu của họ trên Nextcloud.\n\t\tMỗi cá nhân có thể cấu hình các cài đặt riêng liên quan đến Hoạt động trong phần Cài đặt Cá nhân,\n\t\tchọn lựa những Hành động nào sẽ được gửi tới điện thoại, hoặc qua email \n\t\thoặc, liệu một bản tóm tắt hàng ngày sẽ được gửi tới vào mỗi buổi sáng .\n\t\tĐể tìm hiểu thêm, vui lòng đọc tài liệu về Hành động.",
    "Activity notification configuration" : "Cấu hình cho thông báo về hoạt động",
    "Send email" : "Gửi email",
    "Send push notification" : "Gửi thông báo đẩy",
    "You need to set up your email address before you can receive notification emails." : "Bạn cần phải thiết lập địa chỉ email trước khi nhận được email thông báo.",
    "Send activity emails" : "Gửi các thư báo về tình trạng hoạt động",
    "As soon as possible" : "Ngay khi có thể",
    "Hourly" : "Hằng giờ",
    "Daily" : "Hằng ngày",
    "Weekly" : "Hằng tuần",
    "No activity yet" : "Chưa có hoạt động nào",
    "Unable to load the activity list" : "Không thể tải danh sách hoạt động",
    "Notification" : "Thông báo",
    "Enable notification emails" : "Bật email thông báo",
    "Choose for which activities you want to get an email or push notification." : "Chọn các hoạt động mà bạn muốn nhận email hoặc thông báo đẩy.",
    "Choose for which activities you want to get a push notification." : "Chọn các hoạt động mà bạn muốn nhận thông báo đẩy.",
    "Daily activity summary" : "Tóm tắt hoạt động trong ngày",
    "Send daily activity summary in the morning" : "Gửi tóm tắt hoạt động hàng ngày vào buổi sáng",
    "Default settings" : "Cài đặt mặc định",
    "Configure the default notification settings for new accounts." : "Thiết lập cài đặt mặc định của phần thông báo cho những tài khoản mới.",
    "Unable to save the settings" : "Không thể lưu cài đặt",
    "Activity feed" : "Nguồn cấp dữ liệu hoạt động",
    "Activity settings" : "Cài đặt Hành động",
    "Enable RSS feed" : "Bật nguồn cấp dữ liệu RSS",
    "RSS feed" : "Nội dung RSS",
    "Copy RSS feed link" : "Sao chép liên kết RSS",
    "Personal notification settings" : "Cài đặt thông báo cá nhân",
    "No more events to load" : "Không có sự kiện nào",
    "This application enables users to view a log of activities about them or about files." : "Ứng dụng này cho phép những người dùng xem nhật ký các hoạt động về họ hoặc về các tệp.",
    "This application enables users to view actions related to their files in Nextcloud.\n\t\tOnce enabled, users will see a new icon “Activity” in their apps menu.\n\t\tWhen clicked, a new page appears for users to track the activity related to files – from new files, to deleted files, move, rename, updates and shared activity.\n\t\tThe user can configure their individual activity settings in their personal menu.\n\t\tThis sets the type of activity to record, as well as whether to the user sees their own activities,\n\t\twhether these are only available online, and whether they get an email digest on a regular basis.\n\t\tMore information is available in the Activity documentation." : "Ứng dụng này cho phép người dùng xem các hành động liên quan để dữ liệu của họ trên Hệ thống\n\t\tKhi cho phép, người dùng sẽ thấy một biểu tượng mới \"Hoạt động\" trong Danh mục ứng dụng của họ\n\t\tKhi nhấp vào, một trang mới sẽ cho phép người dùng theo dõi các thực hiện liên quan đến dữ liệu - từ tạo file, xóa file, di chuyển, đổi tên, tải lên và thực hiện chia sẽ.\n\t\tNgười dùng có thể cấu hình cài đặt hoạt động trong menu cá nhân của họ.\n\t\tĐiều này thiết đặt các loại hoạt động cần ghi lại, cũng như liệu người dùng có thấy hoạt động của riêng họ hay không,\n\t\tcho dù những điều này chỉ có sẵn trực tuyến và liệu chúng có nhận được email thông báo một cách thường xuyên hay không.\n\t\tĐể có thêm thông tin hãy vào mục tài liệu Hoạt động.",
    "Activities" : "Hoạt động",
    "Configure the default notification settings for new users." : "Thiết lập cài đặt thông báo mặc định cho những người dùng mới."
},
"nplurals=1; plural=0;");

==> nextcloud-26.0.11.tgz: nextcloud/apps/activity/l10n/vi.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Khay hoạt động cá nhân được %s",
    "Your feed URL is invalid" : "Khay URL của bạn không hợp lệ",
    "Activity feed" : "Nguồn cấp dữ liệu hoạt động",
    "Your settings have been updated." : "Các thiết lập của bạn vừa được cập nhật",
    "Settings have been updated." : "Các cài đặt đã được cập nhật.",
    "Recent activity" : "Hoạt động gần đây",
    "No activities" : "Không có hoạt động",
    "More activities" : "Hoạt động mở rộng",
    "Daily activity summary for %s" : "Tóm tắt hoạt động hàng ngày cho %s",
    "_and %n more _::_and %n more _" : ["và %n thêm"],
    "All activities" : "Tất cả hoạt động",
    "By others" : "Bởi người khác",
    "By you" : "Bởi bạn",
    "Activity at %s" : "Hoạt động ở %s",
    "Hello %s" : "Xin chào %s",
    "Hello %s," : "Xin chào %s,",
    "There was some activity at %s" : "Có một số hoạt động tại %s",
    "Mail" : "Thư điện tử",
    "Push" : "Đẩy",
    "Activity" : "Hoạt động",
    "Notifications" : "Thông báo",
    "This application enables people to view a log of activities about them, their files or other data." : "Ứng dụng này cho phép người dùng xem ghi chép cá nhân của họ về: các hoạt động gần đây, tệp tin hoặc dữ liệu khác.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Ứng dụng này cho phép người dùng xem các thao tác liên quan đến tệp tin và dữ liệu của họ trên Nextcloud.\n\t\tMỗi cá nhân có thể cấu hình các cài đặt riêng liên quan đến Hoạt động trong phần Cài đặt Cá nhân,\n\t\tchọn lựa những Hành động nào sẽ được gửi tới điện thoại, hoặc qua email \n\t\thoặc, liệu một bản tóm tắt hàng ngày sẽ được gửi tới vào mỗi buổi sáng .\n\t\tĐể tìm hiểu thêm, vui lòng đọc tài liệu về Hành động.",
    "Activity notification configuration" : "Cấu hình cho thông báo về hoạt động",
    "Send email" : "Gửi email",
    "Send push notification" : "Gửi thông báo đẩy",
    "Today" : "Hôm nay",
    "Yesterday" : "Hôm qua",
    "You need to set up your email address before you can receive notification emails." : "Bạn cần phải thiết lập địa chỉ email trước khi nhận được email thông báo.",
    "Send activity emails" : "Gửi các thư báo về tình trạng hoạt động",
    "As soon as possible" : "Ngay khi có thể",
    "Hourly" : "Hằng giờ",
    "Daily" : "Hằng ngày",
    "Weekly" : "Hằng tuần",
    "You commented" : "Bạn đã bình luận",
    "Message deleted by author" : "Tin nhắn đã xóa bởi tác giả",
    "Open {filename}" : "Mở {filename}",
    "in {path}" : "trong {path}",
    "Home" : "Trang chủ",
    "This stream will show events like additions, changes & shares" : "Luồng này sẽ hiển thị các sự kiện như bổ sung, thay đổi & chia sẻ",
    "No activity yet" : "Chưa có hoạt động nào",
    "Activity settings" : "Cài đặt Hành động",
    "Enable RSS feed" : "Bật nguồn cấp dữ liệu RSS",
    "RSS feed" : "Nội dung RSS",
    "Copy RSS feed link" : "Sao chép liên kết RSS",
    "Personal notification settings" : "Cài đặt thông báo cá nhân",
    "Unable to load the activity list" : "Không thể tải danh sách hoạt động",
    "Notification" : "Thông báo",
    "Enable notification emails" : "Bật email thông báo",
    "Choose for which activities you want to get an email or push notification." : "Chọn các hoạt động mà bạn muốn nhận email hoặc thông báo đẩy.",
    "Choose for which activities you want to get a push notification." : "Chọn các hoạt động mà bạn muốn nhận thông báo đẩy.",
    "Daily activity summary" : "Tóm tắt hoạt động trong ngày",
    "Send daily activity summary in the morning" : "Gửi tóm tắt hoạt động hàng ngày vào buổi sáng",
    "Default settings" : "Cài đặt mặc định",
    "Configure the default notification settings for new accounts." : "Thiết lập cài đặt mặc định của phần thông báo cho những tài khoản mới.",
    "Unable to save the settings" : "Không thể lưu cài đặt",
    "No more events to load" : "Không có sự kiện nào",
    "Copied!" : "Đã sao chép!",
    "Not supported!" : "Không được hỗ trợ!",
    "Press ⌘-C to copy." : "Ấn ⌘-C để sao chép",
    "Press Ctrl-C to copy." : "Ấn Ctrl-C để sao chép",
    "{name} (invisible)" : "{name} (ẩn)",
    "{name} (restricted)" : "{name} (hạn chế)",
    "There are no events for this filter" : "Không có sự kiện nào cho bộ lọc này",
    "Activities" : "Hoạt động"
},
"nplurals=1; plural=0;");
